/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.datacollector.bo.queues;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.hibernate.annotations.GenericGenerator;

/**
 * @author mcarpentier - EBM WebSourcing
 * 
 * A {@link ComponentQueuesStatusSnapshot} is the status of all queus for a
 * component at a given time
 * 
 */
@Entity
public class ComponentQueuesStatusSnapshot implements Serializable {

    /**
     * Serial UID
     */
    private static final long serialVersionUID = -1434628041592824361L;

    private String componentQueuesStatusSnapshotId;

    private long time;

    private String server;

    private String component;

    private Set<QueuesStatus> queuesStatus;

    public ComponentQueuesStatusSnapshot() {
        super();
    }

    public ComponentQueuesStatusSnapshot(long time, String server, String component) {
        super();
        this.time = time;
        this.server = server;
        this.component = component;
    }

    public void addQueueStatus(String queueName, long queueValue) {
        if (this.queuesStatus == null) {
            this.queuesStatus = new HashSet<QueuesStatus>();
        }
        this.queuesStatus.add(new QueuesStatus(queueName, queueValue));
    }


    public String getComponent() {
        return this.component;
    }

    @Id
    @GeneratedValue(generator = "system-uuid")
    @GenericGenerator(name = "system-uuid", strategy = "uuid")
    public String getComponentQueuesStatusSnapshotId() {
        return this.componentQueuesStatusSnapshotId;
    }

    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    public Set<QueuesStatus> getQueuesStatus() {
        return this.queuesStatus;
    }

    public long getTime() {
        return this.time;
    }

    public String getServer() {
        return server;
    }

    public void setServer(String server) {
        this.server = server;
    }

    public void setComponent(String component) {
        this.component = component;
    }

    public void setComponentQueuesStatusSnapshotId(String componentQueuesStatusSnapshotId) {
        this.componentQueuesStatusSnapshotId = componentQueuesStatusSnapshotId;
    }


    public void setQueuesStatus(Set<QueuesStatus> queuesStatus) {
        this.queuesStatus = queuesStatus;
    }

    public void setTime(long time) {
        this.time = time;
    }

    /**
     * @see java.lang.Object#equals(Object)
     */
    public boolean equals(Object object) {
        if (!(object instanceof ComponentQueuesStatusSnapshot)) {
            return false;
        }
        ComponentQueuesStatusSnapshot rhs = (ComponentQueuesStatusSnapshot) object;
        return new EqualsBuilder().appendSuper(super.equals(object)).append(this.component,
                rhs.component).append(this.componentQueuesStatusSnapshotId,
                rhs.componentQueuesStatusSnapshotId).append(this.time, rhs.time).append(
                this.server, rhs.server).append(this.queuesStatus, rhs.queuesStatus).isEquals();
    }

    /**
     * @see java.lang.Object#hashCode()
     */
    public int hashCode() {
        return new HashCodeBuilder(1895243157, 1892311561).appendSuper(super.hashCode()).append(
                this.component).append(this.componentQueuesStatusSnapshotId).append(this.time)
                .append(this.server).append(this.queuesStatus).toHashCode();
    }

}
