/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.datacollector.client.service;

import java.net.MalformedURLException;
import java.net.URL;

import org.ow2.petals.jmx.PetalsDeploymentServiceClient;
import org.ow2.petals.jmx.PetalsJMXClient;
import org.ow2.petals.jmx.exception.ConnectionErrorException;
import org.ow2.petals.jmx.exception.DeploymentServiceDoesNotExistException;
import org.ow2.petals.jmx.exception.DeploymentServiceErrorException;
import org.ow2.petals.jmx.exception.PerformActionErrorException;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;

/**
 * @author mcarpentier - EBM WebSourcing
 * 
 * Deals with petals deploy functions
 * 
 */
public class DeployService extends CollectorService {

    public DeployService(PetalsJMXClient petalsJMXClient) {
        super(petalsJMXClient);

    }

    public void deployServiceAssembly(final String filePath) throws DataCollectorClientException {

        try {
            final URL fileURL = new URL(filePath);
            this.getPetalsJMXClient().getDeploymentServiceClient().deploy(fileURL);

        } catch (final MalformedURLException e) {
            throw new DataCollectorClientException(e);
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public String[] getServiceAssemblies() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getDeploymentServiceClient()
                    .getDeployedServiceAssemblies();
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public String[] getServiceAssemblies(String component) throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getDeploymentServiceClient()
                    .getDeployedServiceAssembliesForComponent(component);
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public String getServiceAssemblyState(String serviceAssembly)
            throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getDeploymentServiceClient().getState(
                    serviceAssembly);
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public void shutdownServiceAssembly(final String serviceAssemblyName)
            throws DataCollectorClientException {
        try {

            // We check if the SA is already deployed
            final PetalsDeploymentServiceClient pdsc = this.getPetalsJMXClient()
                    .getDeploymentServiceClient();
            if (pdsc.isServiceAssemblyDeployed(serviceAssemblyName)) {

                // We check its state to know if we can shutdown it
                if (PetalsDeploymentServiceClient.State.STOPPED.equals(pdsc
                        .getState(serviceAssemblyName))) {
                    // We can shutdown it
                    pdsc.shutdown(serviceAssemblyName);

                } else {
                    throw new DataCollectorClientException(
                            "Can't perform shutdown action, the service assembly "
                                    + serviceAssemblyName + " is in the following state: "
                                    + pdsc.getState(serviceAssemblyName));
                }
            } else {
                throw new DataCollectorClientException("The service-assembly "
                        + serviceAssemblyName + " is not deployed.");
            }
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }

    }

    public void startServiceAssembly(final String serviceAssemblyName)
            throws DataCollectorClientException {
        try {

            // We check if the SA is already deployed
            final PetalsDeploymentServiceClient pdsc = this.getPetalsJMXClient()
                    .getDeploymentServiceClient();
            if (pdsc.isServiceAssemblyDeployed(serviceAssemblyName)) {

                // We check its state to know if we can start it
                if (PetalsDeploymentServiceClient.State.SHUTDOWN.equals(pdsc
                        .getState(serviceAssemblyName))
                        || PetalsDeploymentServiceClient.State.STOPPED.equals(pdsc
                                .getState(serviceAssemblyName))) {
                    // We can start it
                    pdsc.start(serviceAssemblyName);

                } else if (PetalsDeploymentServiceClient.State.STARTED.equals(pdsc
                        .getState(serviceAssemblyName))) {

                } else {
                    throw new DataCollectorClientException(
                            "Can't perform start action, the service assembly "
                                    + serviceAssemblyName + " is in the following state: "
                                    + pdsc.getState(serviceAssemblyName));
                }
            } else {
                throw new DataCollectorClientException("The service-assembly "
                        + serviceAssemblyName + " is not deployed.");
            }
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }

    }

    public void stopServiceAssembly(final String serviceAssemblyName)
            throws DataCollectorClientException {
        try {

            // We check if the SA is already deployed
            final PetalsDeploymentServiceClient pdsc = this.getPetalsJMXClient()
                    .getDeploymentServiceClient();
            if (this.getPetalsJMXClient().getDeploymentServiceClient()
                    .isServiceAssemblyDeployed(serviceAssemblyName)) {

                // We check its state to know if we can stop it
                if (PetalsDeploymentServiceClient.State.STARTED.equals(pdsc
                        .getState(serviceAssemblyName))) {
                    // We can stop it
                    pdsc.stop(serviceAssemblyName);
                } else {
                    throw new DataCollectorClientException(
                            "Can't perform stop action, the service assembly "
                                    + serviceAssemblyName + " is in the following state: "
                                    + pdsc.getState(serviceAssemblyName));
                }
            } else {
                throw new DataCollectorClientException("The service-assembly "
                        + serviceAssemblyName + " is not deployed.");
            }
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }

    }

    public void undeployServiceAssembly(final String serviceAssemblyName)
            throws DataCollectorClientException {

        try {
            this.getPetalsJMXClient().getDeploymentServiceClient().undeploy(
                    serviceAssemblyName);
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final DeploymentServiceDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Deployment service", e);
        } catch (final DeploymentServiceErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

}
