/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.datacollector.client.service;

import javax.management.openmbean.CompositeDataSupport;

import org.ow2.petals.jmx.PetalsJMXClient;
import org.ow2.petals.jmx.exception.ConnectionErrorException;
import org.ow2.petals.jmx.exception.PerformActionErrorException;
import org.ow2.petals.jmx.exception.SystemMonitoringDoesNotExistException;
import org.ow2.petals.jmx.exception.SystemMonitoringServiceErrorException;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;

/**
 * @author mcarpentier - EBM WebSourcing
 * 
 * Deals with petals system infos functions
 * 
 */
public class SystemInfoService extends CollectorService {

    public SystemInfoService(PetalsJMXClient petalsJMXClient) {
        super(petalsJMXClient);

    }

    public int getAvailableProcessors() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getAvailableProcessors();
        } catch (final PerformActionErrorException e) {
            return -1;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getCommittedVirtualMemorySize() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getCommittedVirtualMemorySize();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public int getDaemonThreadCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getDaemonThreadCount();
        } catch (final PerformActionErrorException e) {
            return -1;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getFreePhysicalMemorySize() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getFreePhysicalMemorySize();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public int getLoadedClassCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getLoadedClassCount();
        } catch (final PerformActionErrorException e) {
            return -1;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public CompositeDataSupport getMemoryUsage() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getHeapMemoryUsage();
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public int getPendingObjects() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getPendingObjects();
        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public int getPeakThreadCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getPeakThreadCount();
        } catch (final PerformActionErrorException e) {
            return -1;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getProcessCPUTime() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getProcessCpuTime();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public int getThreadCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getThreadCount();
        } catch (final PerformActionErrorException e) {
            return -1;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getTotalLoadedClassCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getTotalLoadedClassCount();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getTotalPhysicalMemorySize() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getTotalPhysicalMemorySize();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getTotalStartedThreadCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getTotalStartedThreadCount();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getUnloadedClassCount() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient()
                    .getUnloadedClassCount();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }

    public long getUptime() throws DataCollectorClientException {
        try {
            return this.getPetalsJMXClient().getSystemMonitoringServiceClient().getUptime();
        } catch (final PerformActionErrorException e) {
            return -1L;
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final SystemMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find System Monitoring service", e);
        } catch (final SystemMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
    }
}
