/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.datacollector.client.service;

import java.util.List;
import java.util.Map;

import org.ow2.petals.jmx.PetalsJMXClient;
import org.ow2.petals.jmx.exception.ConnectionErrorException;
import org.ow2.petals.jmx.exception.PerformActionErrorException;
import org.ow2.petals.jmx.exception.TransportMonitoringDoesNotExistException;
import org.ow2.petals.jmx.exception.TransportMonitoringServiceErrorException;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.dao.DAOException;
import org.ow2.petals.tools.webadmin.datacollector.util.Queuesmanager;

/**
 * @author mcarpentier - EBM WebSourcing
 * 
 * Deals with petals transport monitoring functions
 * 
 */
public class TransportMonitoringService extends CollectorService {
    private final Queuesmanager queuesmanager;

    public TransportMonitoringService(PetalsJMXClient petalsJMXClient) {
        super(petalsJMXClient);
        this.queuesmanager = new Queuesmanager();
    }

    public Map<String, Map<String, Long>> getAllCurrentComponentQueuesStatus(String server)
            throws DataCollectorClientException {
        return this.queuesmanager.getAllCurrentComponentQueuesStatus(server, this);
    }

    public Map<Long, Map<String, Long>> getComponentQueuesStatus(String server, String component)
            throws DataCollectorClientException {
        try {
            return this.queuesmanager.getComponentQueuesStatus(server, component);
        } catch (final DAOException e) {
            throw new DataCollectorClientException("Can't get current queues status", e);
        }
    }

    public int getMaxQueueSize(final String transporterName) throws DataCollectorClientException {
        int result;
        try {

            result = this.getPetalsJMXClient().getTransportMonitoringServiceClient()
                    .getMaxQueueSize(transporterName);

        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException("Can't get max queue size", e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final TransportMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Monitoring Service", e);
        } catch (final TransportMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
        return result;
    }

    public Map<String, Integer> getQueueCurrentSizes(final String transporterName)
            throws DataCollectorClientException {
        Map<String, Integer> result = null;
        try {

            result = this.getPetalsJMXClient().getTransportMonitoringServiceClient()
                    .getCurrentQueueSizes(transporterName);

        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException("Can't get current queue size", e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final TransportMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Monitoring Service", e);
        } catch (final TransportMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }
        return result;
    }

    public List<String> getTransporters() throws DataCollectorClientException {
        List<String> result = null;
        try {

            result = this.getPetalsJMXClient().getTransportMonitoringServiceClient()
                    .getTransporters();

        } catch (final PerformActionErrorException e) {
            throw new DataCollectorClientException("Can't get transporters", e);
        } catch (final ConnectionErrorException e) {
            throw new DataCollectorClientException(e);
        } catch (final TransportMonitoringDoesNotExistException e) {
            throw new DataCollectorClientException("Unable to find Monitoring Service", e);
        } catch (final TransportMonitoringServiceErrorException e) {
            throw new DataCollectorClientException(e);
        }

        return result;
    }

}
