/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.datacollector.util;

import java.util.Properties;

import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.AnnotationConfiguration;
import org.ow2.petals.tools.webadmin.datacollector.bo.message.MessageExchangeSnapshot;
import org.ow2.petals.tools.webadmin.datacollector.bo.queues.ComponentQueuesStatusSnapshot;
import org.ow2.petals.tools.webadmin.datacollector.bo.queues.QueuesStatus;

/**
 * @author mcarpentier
 * 
 * Deals with all hibernate session configuration. Can be improved by loading
 * properties from a file...
 * 
 */
public class HibernateHelper {

    private static SessionFactory sessionFactory;

    private static String DEFAULT_DRIVER = "org.hsqldb.jdbcDriver";

    private static String DEFAULT_URL = "jdbc:hsqldb:hsql://localhost/datacollector-database";

    private static String DEFAULT_USERNAME = "sa";

    private static String DEFAULT_PASSWORD = "";

    /**
     * @return
     * @throws HibernateException
     */
    public static Session getSession() throws HibernateException {
        if (HibernateHelper.sessionFactory == null) {
            /** session not configured, shouldn't happen */
            configureSession(DEFAULT_DRIVER, DEFAULT_URL, DEFAULT_USERNAME, DEFAULT_PASSWORD);
        }
        return HibernateHelper.sessionFactory.openSession();
    }

    /**
     * configure the hibernate session
     * 
     * @param driver
     * @param url
     * @param username
     * @param password
     */
    public static void configureSession(String driver, String url, String username, String password) {
        try {
            final Properties props = new Properties();
            props.setProperty("show_sql", "false");
            props.setProperty("hibernate.connection.driver_class", driver);
            props.setProperty("hibernate.connection.url", url);
            props.setProperty("hibernate.connection.username", username);
            props.setProperty("hibernate.connection.password", password);
            props.setProperty("hibernate.dialect", "org.hibernate.dialect.HSQLDialect");
            // props.setProperty("hibernate.connection.pool_size", "1");
            props.setProperty("hibernate.connection.autocommit", "true");
            // props.setProperty("hibernate.cache.provider_class",
            // "org.hibernate.cache.HashtableCacheProvider");
            props.setProperty("hibernate.cache.provider_class",
                    "org.hibernate.cache.NoCacheProvider");
            props.setProperty("hibernate.hbm2ddl.auto", "update");
            final AnnotationConfiguration configuration = new AnnotationConfiguration();
            configuration.addProperties(props);

            sessionFactory = configuration.addAnnotatedClass(MessageExchangeSnapshot.class)
                    .addAnnotatedClass(ComponentQueuesStatusSnapshot.class).addAnnotatedClass(
                            QueuesStatus.class).buildSessionFactory();

        } catch (final Throwable e) {
            throw new ExceptionInInitializerError(e);
        }
    }
}
